| Title: | Sparse Regression with Paired Covariates |
|---|---|
| Description: | Implements sparse regression with paired covariates (<doi:10.1007/s11634-019-00375-6>). The paired lasso is designed for settings where each covariate in one set forms a pair with a covariate in the other set (one-to-one correspondence). For the optional correlation shrinkage, install 'ashr' (<https://github.com/stephens999/ashr>) and 'CorShrink' (<https://github.com/kkdey/CorShrink>) from GitHub (see README). |
| Authors: | Armin Rauschenberger [aut, cre] (ORCID: <https://orcid.org/0000-0001-6498-4801>) |
| Maintainer: | Armin Rauschenberger <[email protected]> |
| License: | GPL-3 |
| Version: | 1.0.0 |
| Built: | 2026-06-01 10:06:29 UTC |
| Source: | https://github.com/rauschenberger/palasso |
This page lists the main methods for class "palasso".
## S3 method for class 'palasso' predict(object, newdata, model = "paired", s = "lambda.min", max = NULL, ...) ## S3 method for class 'palasso' coef(object, model = "paired", s = "lambda.min", max = NULL, ...) ## S3 method for class 'palasso' weights(object, model = "paired", max = NULL, ...) ## S3 method for class 'palasso' fitted(object, model = "paired", s = "lambda.min", max = NULL, ...) ## S3 method for class 'palasso' residuals(object, model = "paired", s = "lambda.min", max = NULL, ...) ## S3 method for class 'palasso' deviance(object, model = "paired", max = NULL, ...) ## S3 method for class 'palasso' logLik(object, model = "paired", max = NULL, ...) ## S3 method for class 'palasso' summary(object, model = "paired", ...)## S3 method for class 'palasso' predict(object, newdata, model = "paired", s = "lambda.min", max = NULL, ...) ## S3 method for class 'palasso' coef(object, model = "paired", s = "lambda.min", max = NULL, ...) ## S3 method for class 'palasso' weights(object, model = "paired", max = NULL, ...) ## S3 method for class 'palasso' fitted(object, model = "paired", s = "lambda.min", max = NULL, ...) ## S3 method for class 'palasso' residuals(object, model = "paired", s = "lambda.min", max = NULL, ...) ## S3 method for class 'palasso' deviance(object, model = "paired", max = NULL, ...) ## S3 method for class 'palasso' logLik(object, model = "paired", max = NULL, ...) ## S3 method for class 'palasso' summary(object, model = "paired", ...)
object |
palasso object |
newdata |
covariates:
list of matrices, each with |
model |
character |
s |
penalty parameter:
character |
max |
maximum number of non-zero coefficients,
positive integer,
or |
... |
further arguments for
|
By default, the function predict returns
the linear predictor (type="link").
Consider predicting the response (type="response").
Use palasso to fit the paired lasso.
The function palasso fits the paired lasso.
Use this function if you have paired covariates
and want a sparse model.
palasso(y = y, X = X, max = 10, ...)palasso(y = y, X = X, max = 10, ...)
y |
response:
vector of length |
X |
covariates:
list of matrices,
each with |
max |
maximum number of non-zero coefficients:
positive numeric, or |
... |
Let x denote one entry of the list X. See glmnet
for alternative specifications of y and x. Among the further
arguments, family must equal "gaussian", "binomial",
"poisson", or "cox", and penalty.factor must not be
used.
Hidden arguments:
Deactivate adaptive lasso by setting adaptive to FALSE,
activate standard lasso by setting standard to TRUE,
and activate shrinkage by setting shrink to TRUE.
This function returns an object of class palasso.
Available methods include
predict,
coef,
weights,
fitted,
residuals,
deviance,
logLik,
and summary.
Armin Rauschenberger, Iiuliana Ciocanea-Teodorescu, Marianne A. Jonker, Renee X. Menezes, and Mark A. van de Wiel (2020). "Sparse classification with paired covariates." Advances in Data Analysis and Classification 14:571-588. doi:10.1007/s11634-019-00375-6. (Click here to access PDF. Contact: [email protected].)
set.seed(1) n <- 50; p <- 20 y <- rbinom(n=n,size=1,prob=0.5) X <- lapply(1:2,function(x) matrix(rnorm(n*p),nrow=n,ncol=p)) object <- palasso(y=y,X=X,family="binomial") # adaptive=TRUE,standard=FALSE names(object)set.seed(1) n <- 50; p <- 20 y <- rbinom(n=n,size=1,prob=0.5) X <- lapply(1:2,function(x) matrix(rnorm(n*p),nrow=n,ncol=p)) object <- palasso(y=y,X=X,family="binomial") # adaptive=TRUE,standard=FALSE names(object)